% Computes the naive transportation distance between point sets A & B.
% Assumes each point has equal mass unless specified otherwise.
% Usage: d = naive_distance(A, B, varargin)
%        A = locations of points in distribution 1
%        B = locations of points in distribution 2
%        Optional Arguments:
%        (If not specified, we assume the weight distributions over the points are uniform.)
%        P = weights of points in distribution 1
%        Q = weights of points in distribution 2

function d = naive_distance(A, B, varargin)

  if nargin == 2 % Assume uniform weights
    P = ones(length(A),1)/length(A);
    Q = ones(length(B),1)/length(B);
  elseif nargin == 4
    P = varargin{1};
    Q = varargin{2};
  else
    error('Wrong number of arguments supplied.  Type ''help distance_naive'' for assistance.\n');
  end

  d = 0;
  for i = 1:length(A)
      a = A(i,:); % Position of point
      p = P(i);   % Weight of point
      for j = 1:length(B)
        b = B(j, :); % Position of point
        q = Q(j);    % Weight of point
        
        d = d + p*q*norm(a-b,2);  % Increase sum by weighted Euclidean distance between points
      end
  end
  
  