% Computes the similarity distance between point sets A & B.
% Assumes each point has equal mass unless specified otherwise.
% Usage: d = similarity_distance(A, B, varargin)
%        A = locations of points in distribution 1
%        B = locations of points in distribution 2
%        Optional Arguments:
%        (If not specified, we assume the weight distributions over the points are uniform.)
%        P = weights of points in distribution 1
%        Q = weights of points in distribution 2

function d = similarity_distance(A, B, varargin)

  if nargin == 2 % Assume uniform weights
    P = ones(1,length(A))/length(A);
    Q = ones(1,length(B))/length(B);
  elseif nargin == 4
    P = varargin{1};
    Q = varargin{2};
  else
    error('Wrong number of arguments supplied.  Type ''help distance_similarity'' for assistance.\n');
  end
  
  
  
  d = optimal_distance(A,B,P,Q)/naive_distance(A,B,P,Q);
  %fprintf('Datasets A and B have optimal distance %f\n', optimal_distance(A,B,P,Q));
  %fprintf('Datasets A and B have naive distance %f\n', naive_distance(A,B,P,Q));