% Computes the optimal transportation distance between point sets A & B.
% Assumes each point has equal mass unless specified otherwise.
% Usage: d = optimal_distance(A, B, varargin)
%        A = locations of points in distribution 1
%        B = locations of points in distribution 2
%        Optional Arguments:
%        (If not specified, we assume the weight distributions over the points are uniform.)
%        P = weights of points in distribution 1
%        Q = weights of points in distribution 2

function d = worst_distance(A, B, varargin)

  if nargin == 2 % Assume uniform weights
    P = ones(1,length(A))/length(A);
    Q = ones(1,length(B))/length(B);
  elseif nargin == 4
    P = varargin{1};
    Q = varargin{2};
  else
    error('Wrong number of arguments supplied.  Type ''help distance_optimal'' for assistance.\n');
  end

  % This is a fast way to compute a large number of pair-wise Euclidean distances between all the points
  m = size(A,1); n = size(B,1);
  dists = zeros(m,n);
  for i=1:m
    point = A(i,:);
    repped_point = point(ones(1,n),:); % equiv. to repmat(A(i,:),n,1);
    dists(i,:) = sqrt(sum((B-repped_point).^2,2)); 
  end
  % The dists matrix has now been computed
  
  %  You uncomment this line for problem 3 and save this to worst_distance.m
  dists = -dists;
  
  % Now, call the C implementation of the transportation simplex algorithm
  d = ot_mex(dists,P,Q,2000); % The last argument indicates the maximum
                              % number of flow iterations to compute.
                              % It is to insure the code doesn't get
                              % stuck in an endless loop on some
                              % pathological problem.  The mex file
                              % will tell you if this occurs.  In
                              % general, you don't need to worry about
                              % this.
  
  %  You uncomment this line for problem 3 and save this to worst_distance.m
  d = -d;
  